CsoundAndroid class

Implemented types

Constructors

CsoundAndroid({Function? onReady, Function? onStop})

Properties

hashCode → int
The hash code for this object.
no setterinherited
nativeToIsolate ↔ SendPort
getter/setter pair
onDestroyCallback ↔ Function
getter/setter pair
onReadyCallback ↔ Function
getter/setter pair
onStopCallback ↔ Function
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compileCsd(String csdPath) → Future<int>
override
compileCsdSync(String csdPath) → int
override
compileCsdText(String text) → Future<int>
override
compileCsdTextSync(String text) → int
override
compileOrc(String orc) → Future<int>
override
compileOrcSync(String orc) → int
override
destroy({Function? onDestroyed}) → void
override
dispose() → void
evalCode(String code) → Future<double>
override
evalCodeSync(String code) → double
override
get0dbfs() → Future<double>
override
get0dbfsSync() → double
override
getControlChannel(String channelName) → Future<double>
override
getControlChannelSync(String channelName) → double
override
getKsmps() → Future<int>
override
getKsmpsSync() → int
override
getNchnls() → Future<int>
override
getNchnlsSync() → int
override
getSr() → Future<double>
override
getSrSync() → double
override
getStringChannel(String channelName) → Future<String>
override
getStringChannelSync(String channelName) → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(bool p) → void
override
perform() → int
override
readScore(String text) → Future<int>
override
readScoreSync(String text) → int
override
reset() → void
override
resetSync() → void
override
setAudioChannelCallback(String name, Function f) → void
override
setControlChannel(String channelName, double value) → void
override
setControlChannelCallback(String channelName, dynamic callback(double)) → void
override
setOption(String opt) → Future<int>
override
setOptionSync(String opt) → int
override
setStringChannel(String channelName, String value) → void
override
setStringChannelCallback(String channelName, Function callback) → void
override
setTable(int table, List<double> values) → void
override
setTableCallback(int table, Function callback) → void
override
stop() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited